CCL: ctest Struct Reference

CCL

Data Fields
ctest Struct Reference

`#include <ctest.h>`

## Data Fields
const char * | ssname
const char * | ttname
void(* | run )()
int | skip
void * | data
SetupFunc | setup
TearDownFunc | teardown
unsigned int | magic

## Field Documentation

## ◆ data

void* ctest::data

## ◆ magic

unsigned int ctest::magic

## ◆ run

void(* ctest::run) ()

## ◆ setup

SetupFunc ctest::setup

## ◆ skip

int ctest::skip

## ◆ ssname

const char* ctest::ssname

## ◆ teardown

TearDownFunc ctest::teardown

## ◆ ttname

const char* ctest::ttname

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/tests/ctest.h